==> haskell-temporary-1.3-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-temporary.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: temporary
version: 1.3
id: temporary-1.3-41227bpMgK8Lci8YuU0nJm
key: temporary-1.3-41227bpMgK8Lci8YuU0nJm
license: BSD-3-Clause
maintainer: Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/temporary
synopsis: Portable temporary file and directory support
description:
    Functions for creating temporary files and directories.
category: System, Utils
abi: aa15bae0626a93f7986aa943afc2ff36
exposed: True
exposed-modules:
    System.IO.Temp
import-dirs: /usr/lib/ghc-8.4.3/site-local/temporary-1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/temporary-1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/temporary-1.3
hs-libraries: HStemporary-1.3-41227bpMgK8Lci8YuU0nJm
depends:
    base-4.11.1.0 filepath-1.4.2 directory-1.3.1.5 transformers-0.5.5.0
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html: /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-temporary-1.3-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-temporary.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: temporary
version: 1.3
id: temporary-1.3-CxQ0q7WGGs94YebPTlUn9R
key: temporary-1.3-CxQ0q7WGGs94YebPTlUn9R
license: BSD-3-Clause
maintainer: Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/temporary
synopsis: Portable temporary file and directory support
description:
    Functions for creating temporary files and directories.
category: System, Utils
abi: b4b6bbd331f0b187a519b82d4774bc0e
exposed: True
exposed-modules:
    System.IO.Temp
import-dirs: /usr/lib/ghc-8.4.3/site-local/temporary-1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/temporary-1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/temporary-1.3
hs-libraries: HStemporary-1.3-CxQ0q7WGGs94YebPTlUn9R
depends:
    base-4.11.1.0 filepath-1.4.2 directory-1.3.1.5 transformers-0.5.5.0
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html: /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
